<?php

namespace Drupal\open_ai_metadata\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Function to create the Metadata Content types Settings Form.
 */
class MetadataSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'open_ai_metadata.content_settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'metadata_content_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $selected_content_types = \Drupal::state()->get('open_ai_metadata.metadata_content_types');

    $form = [
      '#attributes' => ['enctype' => 'multipart/form-data'],
    ];

    $form['notification_instructions'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Instructions'),
      '#markup' => t('Select the content type(s) for which you want the Open AI metadata features to be used.'),
    ];

    $content_types = \Drupal::entityTypeManager()->getStorage('node_type')->loadMultiple();

    $options = [];
    foreach ($content_types as $content_type) {
      $options[$content_type->id()] = $content_type->label();
    }

    $form['metadata_content_types'] = [
      '#type' => 'checkboxes',
      '#title' => t('Content Types'),
      '#options' => $options,
      '#default_value' => $selected_content_types ? $selected_content_types : [],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = \Drupal::state();
    $checked_values = $form_state->getValue('metadata_content_types');
    $config->set('open_ai_metadata.metadata_content_types', $checked_values);
    \Drupal::messenger()->addMessage('Configurations saved successfully');
  }

}
